<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Common.php 3309 2005-06-09 11:30:28Z andrew $
*/

/**
 * @package    MaxDal
 * @subpackage Statistics
 * @author     Andrew Hill <andrew@m3.net>
 */

require_once MAX_PATH . '/lib/max/DB.php';
require_once MAX_PATH . '/lib/max/Maintenance.php';
require_once MAX_PATH . '/lib/max/Table/Core.php';
require_once MAX_PATH . '/lib/max/Table/Statistics.php';

/**
 * Definitions of class constants.
 */
define('DAL_STATISTICS_COMMON_UPDATE_OI',   0);
define('DAL_STATISTICS_COMMON_UPDATE_HOUR', 1);
define('DAL_STATISTICS_COMMON_UPDATE_BOTH', 2);
    
/**
 * An abstract class that defines the interface and some common methods for the data
 * access layer code for summarising raw data into statistics, for all Max modules.
 *
 * @abstract
 */
class MAX_Dal_Statistics_Common
{
    var $maintenance;
    var $tables;
    var $tempTables;
    
    /**
     * The constructor method.
     *
     * @param string $dbType The database type to use for creating tables.
     */
    function MAX_Dal_Statistics_Common($dbType)
    {
        $this->maintenance = &new Maintenance();
        $this->tables = MAX_Table_Core::singleton($dbType);
        $this->tempTables = MAX_Table_Statistics::singleton($dbType);
    }

    /**
     * A method to find the last time that maintenance statistics was run.
     *
     * @abstract
     * @param integer $type The update type that occurred - that is,
     *                      DAL_STATISTICS_COMMON_UPDATE_OI if the update was
     *                      done on the basis of the operation interval, 
     *                      DAL_STATISTICS_COMMON_UPDATE_HOUR if the update
     *                      was done on the basis of the hour, or
     *                      DAL_STATISTICS_COMMON_UPDATE_BOTH if the update
     *                      was done on the basis of both the operation
     *                      interval and the hour.
     * @param Date $now An optional Date, used to specify the "current time", and
     *                  to limit the method to only look for past maintenance
     *                  statistics runs before this date. Normally only used
     *                  to assist with re-generation of statistics in the event
     *                  of faulty raw tables.
     * @return Date A Date representing the date up to which the statistics
     *              have been summarised, for the specified update type, or
     *              the appropriate date based on raw data if maintenance
     *              statistics has never been run for the Max module before.
     *              Returns null if no raw data is available.
     */
    function getMaintenanceStatisticsLastRunInfo($type, $now = null) {}
    
    /**
     * A method for summarising impressions into a temporary table.
     *
     * @abstract
     * @param Date $start The start date/time to summarise from.
     * @param Date $end The end date/time to summarise to.
     * @return integer The number of conversion rows summarised.
     */
    function summariseImpressions($start, $end) {}

    /**
     * A method for summarising clicks into a temporary table.
     *
     * @param Date $start The start date/time to summarise from.
     * @param Date $end The end date/time to summarise to.
     * @return integer The number of conversion rows summarised.
     */    
    function summariseClicks($start, $end) {}
    
    /**
     * A method for summarising connections into a temporary table.
     *
     * @abstract
     * @param Date $start The start date/time to summarise from.
     * @param Date $end The end date/time to summarise to.
     * @return integer The number of connections summarised.
     */
    function summariseConnections($start, $end) {}

    /**
     * A method to update the intermediate tables with summarised data.
     *
     * @abstract
     * @param Date $start The start date/time to save from.
     * @param Date $end The end date/time to save to.
     */
    function saveIntermediate($start, $end) {}
    
    /**
     * A method to update the summary table from the intermediate tables.
     *
     * @param Date $start The start date/time to update from.
     * @param Date $end The end date/time to update to.
     */
    function saveSummary($start, $end) {}
    
    /**
     * A method to delete old (ie. summarised) raw data.
     *
     * @abstract
     * @param Date $summarisedTo The date/time up to which data have been summarised (i.e. data up
     *                           to and including this date (minus any compact_stats_grace window)
     *                           will be deleted, unless required by the tracking module, where
     *                           installed).
     * @return integer The number of conversions deleted.
     */
    function deleteOldData($summarisedTo) {}
    
    /**
     * A method to store the details logging a maintenance statistics
     * run.
     *
     * @abstract
     * @param Date $start The time that the maintenance statistics run
     *                    started.
     * @param Date $end The time that the maintenance statistics run
     *                  ended.
     * @param integer $type The type of run:
     *                          DAL_STATISTICS_COMMON_UPDATE_OI - The update was
     *                          based on the operation interval;
     *                          DAL_STATISTICS_COMMON_UPDATE_HOUR - The update
     *                          was based on the hour;
     *                          DAL_STATISTICS_COMMON_UPDATE_BOTH - The update
     *                          was based on both the operation interval and hour.
     * @param Date $updateTo The end of the operation interval/hour that has been updated.
     * @param string $report The maintenance statistics run report.
     */
    function logCompletion($start, $end, $type, $updateTo, $report) {}
    
}

?>
