<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: PriorityConstraint.mtp.test.php 3335 2005-06-10 11:41:30Z andrew $
*/

require_once MAX_PATH . '/lib/max/Maintenance/Priority/Constraint.php';
require_once MAX_PATH . '/lib/pear/Date.php';

/**
 * A class for testing the Maintenance_Priority_Constraint class.
 *
 * @package    MaxMaintenance
 * @subpackage TestSuite
 * @author     James Floyd<james@m3.net>
 */
class Maintenance_TestOfPriorityConstraint extends UnitTestCase
{
    
   /**
    * The constructor method.
    */
    function Maintenance_TestOfPriorityConstraint()
    {        
        $this->UnitTestCase();
    }
    
   /**
    * Test factory create
    * Test 1 - Test weekday object created
    * Test 2 - Test date object created
    * Test 3 - Test time object created
    * Test 4 - Test empty object created
    */
    function testFactory()
    {
        // Test 1
        $aConstraint = array(
            'ad_id' => 3,
            'logical' => 'and',
            'type' => 'weekday',
            'comparison' => '==',
            'data' => '0,6',
            'executionorder' => 7
          );
        $obj = &$this->factoryCreate($aConstraint);
        $this->assertIsA($obj, 'MAX_Maintenance_Priority_Constraint_Weekday');
        
        // test values are set
        $this->assertTrue($obj->logical == 'and');
        $this->assertTrue($obj->type == 'weekday');
        $this->assertTrue($obj->comparison == '!=');
        $this->assertTrue($obj->data[1] == 1);
        $this->assertTrue($obj->data[2] == 2);
        $this->assertTrue($obj->data[3] == 3);
        $this->assertTrue($obj->data[4] == 4);
        $this->assertTrue($obj->data[5] == 5);
        $this->assertTrue($obj->executionOrder == 7);
        unset($obj);
        
        // Test 2
        $aConstraint = array(
            'ad_id' => 3,
            'logical' => 'or',
            'type' => 'date',
            'comparison' => '>',
            'data' => '2005-05-05',
            'executionorder' => 1
          );
        $obj = &$this->factoryCreate($aConstraint);
        $this->assertIsA($obj, 'MAX_Maintenance_Priority_Constraint_Date');
        // test values are set
        $this->assertTrue($obj->logical == 'or');
        $this->assertTrue($obj->type == 'date');
        $this->assertTrue($obj->comparison == '<=');
        $this->assertTrue($obj->data[0] == '2005-05-05');
        $this->assertTrue($obj->executionOrder == 1);
        unset($obj);
        
        // Test 3
        $aConstraint = array(
            'ad_id' => 3,
            'logical' => 'and',
            'type' => 'time',
            'comparison' => '==',
            'data' => '0,6,21',
            'executionorder' => 0
          );
        $obj = &$this->factoryCreate($aConstraint);
        $this->assertIsA($obj, 'MAX_Maintenance_Priority_Constraint_Time');
        $this->assertTrue($obj->logical == 'and');
        $this->assertTrue($obj->type == 'time');
        $this->assertTrue($obj->comparison == '!=');
        $this->assertTrue(!isset($obj->data[0]));
        $this->assertTrue($obj->data[1] == 1);
        $this->assertTrue($obj->data[2] == 2);
        $this->assertTrue($obj->data[3] == 3);
        $this->assertTrue($obj->data[4] == 4);
        $this->assertTrue($obj->data[5] == 5);
        $this->assertTrue(!isset($obj->data[6]));
        $this->assertTrue($obj->data[7] == 7);
        $this->assertTrue($obj->data[8] == 8);
        $this->assertTrue($obj->data[9] == 9);
        $this->assertTrue($obj->data[10] == 10);
        $this->assertTrue($obj->data[11] == 11);
        $this->assertTrue($obj->data[12] == 12);
        $this->assertTrue($obj->data[13] == 13);
        $this->assertTrue($obj->data[14] == 14);
        $this->assertTrue($obj->data[15] == 15);
        $this->assertTrue($obj->data[16] == 16);
        $this->assertTrue($obj->data[17] == 17);
        $this->assertTrue($obj->data[18] == 18);
        $this->assertTrue($obj->data[19] == 19);
        $this->assertTrue($obj->data[20] == 20);
        $this->assertTrue(!isset($obj->data[21]));
        $this->assertTrue($obj->data[22] == 22);
        $this->assertTrue($obj->data[23] == 23);
        $this->assertTrue(!isset($obj->data[24]));
        $this->assertTrue($obj->executionOrder == 0);
        unset($obj);
        
        // Test 4 - other constraints not implemented - default empty class returned
        $aConstraint = array(
            'ad_id' => 3,
            'logical' => 'and',
            'type' => 'ip',
            'comparison' => '==',
            'data' => '192.168.22.5',
            'executionorder' => 0
          );
        $obj = &$this->factoryCreate($aConstraint);
        $this->assertIsA($obj, 'MAX_Maintenance_Priority_Constraint_Empty');
        unset($obj);
    }
    
    function testCalculateNonDeliveryRestriction()
    {
        PEAR::pushErrorHandling(null);
        // test method is still abstract, should getr PEAR::error
        $this->assertTrue(is_a(MAX_Maintenance_Priority_Constraint::calculateNonDeliveryRestriction(), 'pear_error'));
        PEAR::popErrorHandling();
    }
    
    function testMinutesPerTimePeriod()
    {
        PEAR::pushErrorHandling(null);
        // test method is still abstract, should getr PEAR::error
        $this->assertTrue(is_a(MAX_Maintenance_Priority_Constraint::minutesPerTimePeriod(), 'pear_error'));
        PEAR::popErrorHandling();
    }
    
    function testTestInterval()
    {
        PEAR::pushErrorHandling(null);
        // test method is still abstract, should getr PEAR::error
        $this->assertTrue(is_a(MAX_Maintenance_Priority_Constraint::testInterval(), 'pear_error'));
        PEAR::popErrorHandling();
    }
    
    function testGetNonDeliveryOperator()
    {   
        $this->assertTrue(MAX_Maintenance_Priority_Constraint::getNonDeliveryOperator('!=') == '==');
        $this->assertTrue(MAX_Maintenance_Priority_Constraint::getNonDeliveryOperator('==') == '!=');
        $this->assertTrue(MAX_Maintenance_Priority_Constraint::getNonDeliveryOperator('>') == '<=');
        $this->assertTrue(MAX_Maintenance_Priority_Constraint::getNonDeliveryOperator('<') == '>=');
        $this->assertTrue(MAX_Maintenance_Priority_Constraint::getNonDeliveryOperator('<=') == '>');
        $this->assertTrue(MAX_Maintenance_Priority_Constraint::getNonDeliveryOperator('>=') == '<');
        
        PEAR::pushErrorHandling(null);
        $this->assertTrue(is_a(MAX_Maintenance_Priority_Constraint::getNonDeliveryOperator('hello'), 'pear_error'));
        PEAR::popErrorHandling();
    }
    
    function &factoryCreate($aConstraint)
    {
        return MAX_Maintenance_Priority_Constraint::factory($aConstraint);
    }
}

?>
