<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: PriorityConstraintWeekday.mtp.test.php 3335 2005-06-10 11:41:30Z andrew $
*/

require_once MAX_PATH . '/lib/max/Maintenance/Priority/Constraint.php';
require_once MAX_PATH . '/lib/max/Maintenance/Priority/Constraint/Weekday.php';
require_once MAX_PATH . '/lib/pear/Date.php';

/**
 * @package    MaxMaintenance
 * @subpackage TestSuite
 * @author     James Floyd <james@m3.net>
 */
class Delivery_TestOfPriorityConstraintWeekday extends UnitTestCase
{
   /**
    * The constructor method.
    */
    function Delivery_TestOfPriorityConstraintWeekday()
    {        
        $this->UnitTestCase();
    }
    
    function testCalculateNonDeliveryRestrictions()
    {
        // Test 1 - test non delivery restrictions are being set
        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'weekday',
            'comparison' => '==',
            'data' => '0,2,5',
            'executionorder' => 1,
        );
        $days = range(0,6);
        unset($days[0], $days[2], $days[5]);
        $oLimitationWeekday = & MAX_Maintenance_Priority_Constraint::factory($aLimitation);
        $oLimitationWeekday->calculateNonDeliveryRestrictions();
        $this->assertTrue(count($oLimitationWeekday->data) == 4);
        $this->assertTrue($oLimitationWeekday->data == $days);
        unset($aLimitation, $oLimitationWeekday, $days);
    }
    
    function testMinutesPerTimePeriod()
    {
       $aConstraint = array(
            'ad_id' => 3,
            'logical' => 'and',
            'type' => 'weekday',
            'comparison' => '==',
            'data' => '0,6',
            'executionorder' => 0
       );
       $obj = &$this->getInstance($aConstraint);
       $this->assertEqual(10080, $obj->minutesPerTimePeriod());
    }
    
    function testTestInterval()
    {
        Mock::generatePartial('MAX_Maintenance_Priority_Constraint_Weekday', $mockClass = 'MAX_Maintenance_Priority_Constraint_Weekday' . rand(),
            array('calculateNonDeliveryRestrictions'));
        $obj =& new $mockClass($this);
        
        $obj->setReturnValue('calculateNonDeliveryRestrictions', true);
        
        $aLimitation = array(
            'ad_id' => 1,
            'logical' => 'and',
            'type' => 'weekday',
            'comparison' => '==',
            'data' => '1, 5, 4, 6',
            'executionorder' => 1,
        );
        $aData = range(0,6);
        unset($aData[1], $aData[5], $aData[4], $aData[6]);
        $obj->MAX_Maintenance_Priority_Constraint_Weekday($aLimitation);
        
        // set fake delivery restrictions that should be set by calculateNonDeliveryRestrictions()
        $obj->data = $aData;
        
        $oTestStartDate = new Date('2005-05-15 00:00:00');
        
        foreach (range(0,6) as $key => $hour) {
            if (in_array($key, $aData)) {
                $this->assertTrue($obj->testInterval($oTestStartDate) == true);
            } else {
                $this->assertTrue($obj->testInterval($oTestStartDate) == false);
            }
            // move test date on by one day
            $oTestStartDate->addSeconds(SECONDS_PER_DAY);
        }
    }
    
    function &getInstance($aConstraint)
    {
        return new MAX_Maintenance_Priority_Constraint_Weekday($aConstraint);
    }
}

?>
